@@ -17,5 +17,5 @@
 #    You should have received a copy of the GNU General Public License
 #    along with obob_subjectdb. If not, see <http://www.gnu.org/licenses/>.
 
-from .jobcluster import JobCluster, PermuteArgument  # noqa
+from .jobcluster import JobCluster, SingularityJobCluster, PermuteArgument  # noqa
 from .job import Job, AutomaticFilenameJob  # noqa
