@@ -5,5 +5,8 @@
 #SBATCH --array=1-{{ n_jobs }}
 #SBATCH --time={{ request_time }}
 #SBATCH --output={{ log_dir }}/out_%a.log
+{% if exclude_nodes %}
+#SBATCH --exclude="{{ exclude_nodes }}"
+{% endif %}
 
 {{ executable }} {{ arguments }}
\ No newline at end of file
